Index: services/ui/ws/display.h |
diff --git a/services/ui/ws/display.h b/services/ui/ws/display.h |
index f4b244d4f7fbc2987bd788457376e95a80926c9e..b0e170386efd798b1fbdb37f1667be738e0bc8ec 100644 |
--- a/services/ui/ws/display.h |
+++ b/services/ui/ws/display.h |
@@ -162,7 +162,11 @@ class Display : public PlatformDisplayDelegate, |
using WindowManagerDisplayRootMap = |
std::map<UserId, WindowManagerDisplayRoot*>; |
- // Inits the necessary state once the display is ready. |
+ // Inits the display root once the display is ready in |
+ // 'external window mode'. |
+ void InitDisplayRoot(); |
+ |
+ // Inits the necessary WindowManager state once the display is ready. |
void InitWindowManagerDisplayRoots(); |
// Creates the set of WindowManagerDisplayRoots from the |
@@ -219,6 +223,8 @@ class Display : public PlatformDisplayDelegate, |
WindowManagerDisplayRootMap window_manager_display_root_map_; |
+ std::unique_ptr<WindowManagerDisplayRoot> external_mode_root_; |
+ |
DISALLOW_COPY_AND_ASSIGN(Display); |
}; |